/* Includes ------------------------------------------------------------------*/
#include "board.h"


/**
 * @brief BOARD BSP Driver version number
   */
#define __BOARD_BSP_VERSION_MAIN   (0x01) /*!< [31:24] main version */
#define __BOARD_BSP_VERSION_SUB1   (0x01) /*!< [23:16] sub1 version */
#define __BOARD_BSP_VERSION_SUB2   (0x00) /*!< [15:8]  sub2 version */
#define __BOARD_BSP_VERSION_RC     (0x00) /*!< [7:0]  release candidate */
#define __BOARD_BSP_VERSION            ((__BOARD_BSP_VERSION_MAIN << 24)\
									  |(__BOARD_BSP_VERSION_SUB1 << 16)\
									  |(__BOARD_BSP_VERSION_SUB2 << 8 )\
									  |(__BOARD_BSP_VERSION_RC))
/**
  * @}
  */


/** @defgroup BOARD_Private_Macros Private Macros
  * @{
  */

/**
  * @}
  */


/* Sensors IO functions */
void     SENSOR_IO_Init(void);
void     SENSOR_IO_DeInit(void);
void     SENSOR_IO_Write(uint8_t Addr, uint8_t Reg, uint8_t Value);
uint8_t  SENSOR_IO_Read(uint8_t Addr, uint8_t Reg);
uint16_t SENSOR_IO_ReadMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
void     SENSOR_IO_WriteMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
HAL_StatusTypeDef SENSOR_IO_IsDeviceReady(uint16_t DevAddress, uint32_t Trials);
void     SENSOR_IO_Delay(uint32_t Delay);

/* DSRC IO functions */
/*void DSRC_IO_Init(void);
void DRSC_IO_DeInit(void);
void DRSC_IO_Write(uint8_t *pBuffer, uint16_t NumByteToWrite);
uint16_t DRSC_IO_Read(uint8_t *pBuffer);*/

/* Charger IO functions */
void     CHARGER_IO_Init(void);
void     CHARGER_IO_DeInit(void);
void     CHARGER_IO_Write(uint8_t Addr, uint8_t Reg, uint8_t Value);
uint8_t  CHARGER_IO_Read(uint8_t Addr, uint8_t Reg);
uint16_t CHARGER_IO_ReadMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
void     CHARGER_IO_WriteMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
HAL_StatusTypeDef CHARGER_IO_IsDeviceReady(uint16_t DevAddress, uint32_t Trials);
void     CHARGER_IO_Delay(uint32_t Delay);

/* GNSS IO functions */
void GNSS_IO_Power(FunctionalState on);



uint32_t BSP_GetVersion(void)
{
  return __BOARD_BSP_VERSION;
}



/*******************************************************************************
                            BUS OPERATIONS
*******************************************************************************/



/*******************************************************************************
                            LINK OPERATIONS
*******************************************************************************/

/******************************** LINK NB  ********************************/
extern UART_HandleTypeDef NB_UART_BUS_HANDLER;

void NB_SendData(uint8_t *data, uint16_t len, uint8_t enter)
{
	uint8_t delimiter[2]={'\r', '\n'};
	while(NB_UART_BUS_HANDLER.gState != HAL_UART_STATE_READY);
	while(HAL_UART_Transmit_DMA(&NB_UART_BUS_HANDLER, data, len) == HAL_BUSY);
	while(NB_UART_BUS_HANDLER.gState != HAL_UART_STATE_READY);
	if (enter)
	{
		while(HAL_UART_Transmit_DMA(&NB_UART_BUS_HANDLER, delimiter, 1) == HAL_BUSY);
		while(NB_UART_BUS_HANDLER.gState != HAL_UART_STATE_READY);
	}
}

void HAL_UART_TxCpltCallback(UART_HandleTypeDef *huart)
{
	if ((huart->gState == HAL_UART_STATE_BUSY_TX) && (HAL_IS_BIT_SET(huart->Instance->CR3, USART_CR3_DMAT)))
	  {
		/* Disable TXEIE and TCIE interrupts */
		CLEAR_BIT(huart->Instance->CR1, (USART_CR1_TXEIE | USART_CR1_TCIE));
	    CLEAR_BIT(huart->Instance->CR3, USART_CR3_DMAT);
	    /* Abort the UART DMA Tx channel */
	    if(huart->hdmatx != NULL) HAL_DMA_Abort(huart->hdmatx);
	    /* At end of Tx process, restore huart->gState to Ready */
	    huart->gState = HAL_UART_STATE_READY;
	  }
}

void HAL_UART_RxCpltCallback(UART_HandleTypeDef *huart)
{
	if (huart->Instance == CMDLINE_UART) CmdLine_SaveByte(rxData);
	if (huart->Instance == NB_UART) NB_SaveByte(&rxNB);
}

void HAL_UART_ErrorCallback(UART_HandleTypeDef *huart)
{
	if (huart->ErrorCode != HAL_UART_ERROR_ORE) return;
	if (huart->Instance == CMDLINE_UART) CmdLine_SaveByte((uint8_t)(huart->Instance->RDR & (uint8_t)0x00FF));
	if (huart->Instance == NB_UART) NB_SaveByte((uint8_t*)(huart->Instance->RDR & (uint8_t)0x00FF));
}

int _write (int fd, char *ptr, int len)
{
	while(CMDLINE_UART_BUS_HANDLER.gState != HAL_UART_STATE_READY);
	HAL_UART_Transmit_DMA(&CMDLINE_UART_BUS_HANDLER, (uint8_t *)ptr, len);
	while(CMDLINE_UART_BUS_HANDLER.gState != HAL_UART_STATE_READY);
	return len;
}


/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
